@@ -8,9 +8,9 @@ use Carp qw(croak);
 # instead of using the shared one from app. Who knows
 # what all the others are doing to the poor thing.
 
-my $ua = Mojo::UserAgent->new( cookie_jar => 0 );
+my $ua = Mojo::UserAgent->new(cookie_jar => Mojo::UserAgent::CookieJar->new(ignore => sub { 1 }));
 
-our $VERSION = '0.703';
+our $VERSION = '0.704';
 
 my $make_req = sub {
     my $c = shift;
